summaryrefslogtreecommitdiff
path: root/usr.bin/ssh/packet.h
diff options
context:
space:
mode:
authorMarkus Friedl <markus@cvs.openbsd.org>2000-01-04 16:54:59 +0000
committerMarkus Friedl <markus@cvs.openbsd.org>2000-01-04 16:54:59 +0000
commit0c5c163fb16aa031858217f2bfd721cfb9b8fbaa (patch)
treed313dbe49528b358eb1cccc988ad542dad994963 /usr.bin/ssh/packet.h
parent9c90131ce98bee1a3d3dd773429cb3b5d423efe2 (diff)
allow auth-kerberos for IPv4 only
Diffstat (limited to 'usr.bin/ssh/packet.h')
-rw-r--r--usr.bin/ssh/packet.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/usr.bin/ssh/packet.h b/usr.bin/ssh/packet.h
index 2e846546521..055f2c8810c 100644
--- a/usr.bin/ssh/packet.h
+++ b/usr.bin/ssh/packet.h
@@ -13,7 +13,7 @@
*
*/
-/* RCSID("$Id: packet.h,v 1.8 2000/01/04 00:07:59 markus Exp $"); */
+/* RCSID("$Id: packet.h,v 1.9 2000/01/04 16:54:58 markus Exp $"); */
#ifndef PACKET_H
#define PACKET_H
@@ -191,7 +191,8 @@ do { \
} \
} while (0)
/* remote host is connected via a socket */
int packet_connection_is_on_socket(void);
+int packet_connection_is_ipv4(void);
#endif /* PACKET_H */
@@ -191,7 +191,8 @@ do { \
} \
} while (0)
-/* remote host is connected via a socket */
+/* remote host is connected via a socket/ipv4 */
int packet_connection_is_on_socket(void);